@@ -24,18 +24,24 @@ def init_whisper_and_ctx(libname, fname_model):
 def _execute_whisper_full(
     data = None, 
     whisper = None,
-    ctx = None
+    ctx = None,
+    language = b'en',
+    n_threads = 4,
+    print_realtime = False,
+    print_progress = False,
+    suppress_non_speech_tokens = True
 ):
     assert data is not None
     assert whisper is not None and ctx is not None  
     assert type(data) is not str
+    assert type(language) is bytes
 
     params = whisper.whisper_full_default_params(0)
-    params.n_threads = 4
-    params.print_realtime = False 
-    params.print_progress = False
-    params.suppress_non_speech_tokens = True
-    params.language = b'ko'
+    params.n_threads = n_threads
+    params.print_realtime = print_realtime 
+    params.print_progress = print_progress
+    params.suppress_non_speech_tokens = suppress_non_speech_tokens
+    params.language = language
 
     result = whisper.whisper_full(ctypes.c_void_p(ctx), params, data.ctypes.data_as(ctypes.POINTER(ctypes.c_float)), len(data))
     n_seg = whisper.whisper_full_n_segments(ctypes.c_void_p(ctx))
@@ -78,7 +84,12 @@ def run_whisper(
     data,
     libname, 
     fname_model,
-    WINDOW_SIZE = 16000 * 30 * 2
+    WINDOW_SIZE = 16000 * 30 * 2,
+    language = b'en',
+    n_threads = 4,
+    print_realtime = False,
+    print_progress = False,
+    suppress_non_speech_tokens = True
 ):
     """Run whisper and Return list of segment dict. 
 
@@ -94,7 +105,16 @@ def run_whisper(
     total_length = data.shape[0]
     spokens = []
     for start in range(0, total_length, WINDOW_SIZE):
-        res = _execute_whisper_full(data = data[start:start+WINDOW_SIZE].copy(), whisper = whisper, ctx = ctx)
+        res = _execute_whisper_full(
+                data = data[start:start+WINDOW_SIZE].copy(), 
+                whisper = whisper, 
+                ctx = ctx,
+                language = language,
+                n_threads = n_threads,
+                print_realtime = print_realtime,
+                print_progress = print_progress,
+                suppress_non_speech_tokens = suppress_non_speech_tokens
+            )
         for segment in res:
             segment['start'] += start
             segment['end'] += start
